pub async fn execute(force: bool) -> Result<()>
Execute the system-wide init command
Returns an error if the configuration cannot be loaded, directories cannot be created, or system integration files fail to install.