TemplateCommand

Enum TemplateCommand 

pub enum TemplateCommand {
    List,
    Create {
        template: String,
        output: PathBuf,
        variables: Vec<String>,
    },
    Info {
        template: String,
    },
    Validate {
        manifest: PathBuf,
    },
}
Template subcommands

Variants



List

List available templates



Create

Create a new project from template

Fields

template: String

Template name

output: PathBuf

Output directory

variables: Vec<String>

Template variables in key=value format



Info

Show detailed information about a template

Fields

template: String

Template name



Validate

Validate a template manifest

Fields

manifest: PathBuf

Path to template manifest

Implementations

Source

impl TemplateCommand

pub async fn execute(&self) -> Result<()>

Execute the template command

Errors

Returns an error if the template cannot be found, variables are invalid, or the project files cannot be written.