execute

Function execute 

pub async fn execute(
    path: Option<PathBuf>,
    ai_report: bool,
    locked_only: bool,
) -> Result<()>
Execute the validate command

Errors

Returns an error if the configuration cannot be loaded, the validator fails to initialize, or the validation process encounters an I/O error.