pub struct HierarchicalLockManager { /* private fields */ }Expand description
Hierarchical lock manager that respects precedence
Implementations
Sourceimpl HierarchicalLockManager
impl HierarchicalLockManager
Sourcepub fn is_locked(&self, key: &str) -> Option<(ConfigLevel, &LockEntry)>
pub fn is_locked(&self, key: &str) -> Option<(ConfigLevel, &LockEntry)>
Check if a key is locked at any level
Returns the most specific lock (project > user > system)
Sourcepub fn is_locked_at_level(
&self,
key: &str,
level: ConfigLevel,
) -> Option<&LockEntry>
pub fn is_locked_at_level( &self, key: &str, level: ConfigLevel, ) -> Option<&LockEntry>
Check if a specific level has a lock
Sourcepub fn get_effective_locks(&self) -> HashMap<String, (ConfigLevel, LockEntry)>
pub fn get_effective_locks(&self) -> HashMap<String, (ConfigLevel, LockEntry)>
Get all locks merged with proper precedence
Sourcepub async fn lock(
&mut self,
key: impl Into<String>,
value: impl Into<String>,
reason: impl Into<String>,
level: ConfigLevel,
) -> Result<()>
pub async fn lock( &mut self, key: impl Into<String>, value: impl Into<String>, reason: impl Into<String>, level: ConfigLevel, ) -> Result<()>
Sourcepub async fn unlock(
&mut self,
key: &str,
level: ConfigLevel,
reason: &str,
) -> Result<LockEntry>
pub async fn unlock( &mut self, key: &str, level: ConfigLevel, reason: &str, ) -> Result<LockEntry>
Unlock a key at a specific level
Errors
Returns an error if the key is not locked at this level or if saving fails.
Sourcepub fn status_report(&self) -> String
pub fn status_report(&self) -> String
Get lock status report