pub struct ConfigValidator;Expand description
Configuration change validator that checks locks before allowing changes
Implementations
Sourceimpl ConfigValidator
impl ConfigValidator
Sourcepub async fn validate_change(key: &str, new_value: &str) -> Result<()>
pub async fn validate_change(key: &str, new_value: &str) -> Result<()>
Validate a configuration change against locks
Errors
Returns an error if the change violates a lock.
Sourcepub async fn can_modify(key: &str, new_value: &str) -> bool
pub async fn can_modify(key: &str, new_value: &str) -> bool
Check if a key can be modified (not locked or same value)