Module git_hooks

Module git_hooks 

Git hooks installation and management Git hooks installation and management

This module provides functionality to install and manage git hooks for automatic validation on commits.

@task T017 @epic T014

Functions

check_hooks_status
Check if mandatory safety hooks are installed
install_git_hooks
Install mandatory blocking git hooks for a project
uninstall_git_hooks
Remove git hooks from a project