pub async fn install_git_hooks(project_path: &Path) -> Result<()>Expand description
Install git hooks for a project
Errors
Returns Error::Validation if the path is not a git repository.
Returns Error::Process if hook files cannot be written.
pub async fn install_git_hooks(project_path: &Path) -> Result<()>Install git hooks for a project
Returns Error::Validation if the path is not a git repository.
Returns Error::Process if hook files cannot be written.