GitHubClient

Struct GitHubClient 

pub struct GitHubClient { /* private fields */ }
GitHub API client

Implementations

Source

impl GitHubClient

pub fn new(auth_token: Option<String>) -> Result<Self>

Create a new GitHub client

Errors

Returns an error if the HTTP client cannot be constructed.

pub async fn get_latest_release(&self) -> Result<GitHubRelease>

Get the latest stable release

Errors

Returns an error if the GitHub API request fails, the response status indicates an error, or the response JSON cannot be parsed.

pub async fn get_releases(&self, count: usize) -> Result<Vec<GitHubRelease>>

Get multiple recent releases

Errors

Returns an error if the GitHub API request fails, the response status indicates an error, or the response JSON cannot be parsed.