pub async fn quick_security_check() -> Result<bool>
Quick security check for use during startup
Returns true if no critical issues found, false otherwise.
Returns an error if the security check fails to execute.