pub struct SecurityChecker { /* private fields */ }Expand description
Security advisory checker
Implementations
Sourceimpl SecurityChecker
impl SecurityChecker
Sourcepub fn new() -> Result<Self>
pub fn new() -> Result<Self>
Create a new security checker
Errors
Returns an error if the version manager or cache cannot be initialized.
Sourcepub async fn check_current_version(&self) -> Result<SecurityCheckResult>
pub async fn check_current_version(&self) -> Result<SecurityCheckResult>
Check current Rust version for security issues
Errors
Returns an error if the current version cannot be detected or if the security check fails.
Sourcepub fn display_results(result: &SecurityCheckResult)
pub fn display_results(result: &SecurityCheckResult)
Display security check results