quick_security_check

Function quick_security_check 

pub async fn quick_security_check(project_path: &Path) -> Result<bool>
Quick security check (non-blocking)

Errors

Returns an error if the audit cannot be executed. Audit failures are treated as passing to avoid blocking the caller.