pub struct TemplateRepository { /* private fields */ }Expand description
Template repository manager
Implementations
Sourceimpl TemplateRepository
impl TemplateRepository
Sourcepub fn new() -> Result<Self>
pub fn new() -> Result<Self>
Create a new template repository manager
Errors
Returns an error if the cache directory cannot be created or accessed.
Sourcepub fn list_cached(&self) -> Vec<&CachedTemplate>
pub fn list_cached(&self) -> Vec<&CachedTemplate>
List all cached templates
Sourcepub fn get_cached(&self, name: &str) -> Option<&CachedTemplate>
pub fn get_cached(&self, name: &str) -> Option<&CachedTemplate>
Get a cached template by name
Sourcepub fn add_to_cache(&mut self, template: CachedTemplate) -> Result<()>
pub fn add_to_cache(&mut self, template: CachedTemplate) -> Result<()>
Sourcepub fn remove_from_cache(&mut self, name: &str) -> Result<()>
pub fn remove_from_cache(&mut self, name: &str) -> Result<()>
Remove a template from cache
Errors
Returns an error if the cached directory or index cannot be updated.
Sourcepub fn cache_directory(&self) -> &Path
pub fn cache_directory(&self) -> &Path
Get cache directory path
Sourcepub fn template_cache_path(&self, name: &str) -> PathBuf
pub fn template_cache_path(&self, name: &str) -> PathBuf
Get the path where a template should be cached