Module git_hooks

Module git_hooks 

Git hooks installation and management Git hooks installation and management

This module provides functionality to install and manage git hooks for automatic validation on commits.

Functions

install_git_hooks
Install git hooks for a project
uninstall_git_hooks
Remove git hooks from a project