Git hooks installation and management Git hooks installation and management
This module provides functionality to install and manage git hooks for automatic validation on commits.
@task T017 @epic T014
Functions
- check_
hooks_ status - Check if mandatory safety hooks are installed
- install_
git_ hooks - Install mandatory blocking git hooks for a project
- uninstall_
git_ hooks - Remove git hooks from a project