pub struct GitHubClient { /* private fields */ }Expand description
GitHub API client
Implementations
Sourceimpl GitHubClient
impl GitHubClient
Sourcepub async fn get_latest_release(&self) -> Result<GitHubRelease>
pub async fn get_latest_release(&self) -> Result<GitHubRelease>
Get the latest stable release
Errors
Returns an error if the GitHub API request fails, the response status indicates an error, or the response JSON cannot be parsed.
Sourcepub async fn get_releases(&self, count: usize) -> Result<Vec<GitHubRelease>>
pub async fn get_releases(&self, count: usize) -> Result<Vec<GitHubRelease>>
Get multiple recent releases
Errors
Returns an error if the GitHub API request fails, the response status indicates an error, or the response JSON cannot be parsed.