pub async fn quick_security_check(project_path: &Path) -> Result<bool>Expand description
Quick security check (non-blocking)
Errors
Returns an error if the audit cannot be executed. Audit failures are treated as passing to avoid blocking the caller.